Package: shinyr
Type: Package
Title: Data Insights Through Inbuilt R Shiny App
Version: 0.4.2
Authors@R: c(person("Jayachandra", "N", email = "itsjay510@gmail.com", role = c("aut", "cre")), 
    person("Pushker", "Ravindra", email = "pushker@gmail.com", role = c("aut")))
Description: It builds dynamic R shiny based dashboards to analyze any CSV files. It provides simple dashboard design to subset the data, perform exploratory data analysis and preliminary machine learning (supervised and unsupervised). It also provides filters based on columns of interest. 
Depends: R (>= 3.5.0),
Imports: dplyr, shiny, shinydashboard, tm, wordcloud, corrplot,
        randomForest, RColorBrewer, caret, nnet, plotly
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-02-03 14:15:51 UTC; RPUSH1
Author: Jayachandra N [aut, cre],
  Pushker Ravindra [aut]
Maintainer: Jayachandra N <itsjay510@gmail.com>
Repository: CRAN
Date/Publication: 2025-02-03 19:30:02 UTC
Built: R 4.6.0; ; 2026-04-30 16:44:30 UTC; unix
