# Generated by roxygen2: do not edit by hand

export(confmatrix)
export(dataPartition)
export(detectClass)
export(excludeThese)
export(getCoefficients)
export(getDataInsight)
export(getFeqTable)
export(getLibraryReport)
export(getMostRepeatedValue)
export(getType)
export(getTypeOfColumns)
export(getWordCloud)
export(getcharacterCols)
export(getnumericCols)
export(groupByandSumarize)
export(imputeMyData)
export(make_var)
export(missing_count)
export(multinomial)
export(plotCor)
export(randomForestModel)
export(regressionModelMetrics)
export(shineMe)
export(splitAndGet)
export(valid_sets)
import(RColorBrewer)
import(dplyr)
import(plotly)
import(shiny)
import(shinydashboard)
importFrom(caret,confusionMatrix)
importFrom(corrplot,corrplot)
importFrom(nnet,multinom)
importFrom(randomForest,randomForest)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,IQR)
importFrom(stats,cor)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,sd)
importFrom(tm,Corpus)
importFrom(tm,DataframeSource)
importFrom(tm,TermDocumentMatrix)
importFrom(tm,VectorSource)
importFrom(tm,content_transformer)
importFrom(tm,removeNumbers)
importFrom(tm,removePunctuation)
importFrom(tm,removeWords)
importFrom(tm,stopwords)
importFrom(tm,stripWhitespace)
importFrom(tm,tm_map)
importFrom(utils,data)
importFrom(wordcloud,wordcloud)
