shinyr: Data Insights Through Inbuilt R Shiny App
================

1.  Do you want to get insights of your data without much efforts?
2.  Do you want to build a shiny dashboard for your own data?
3.  Do you want to perform analysis on your data by subseting it
    dynamically?
4.  Do you want to perform initial analysis on your data with just few
    clicks?
5.  All these are possible with shinyr without doing much programming\!
    you just have to run one single command and upload your data.

<!-- end list -->

``` r
install.packages("shinyr")
library(shinyr)
shinyr::shineMe()
```

#### Remember your data stays with you safe\! your data will not be exposed to anyone/anywhere.
